@@ -4,8 +4,11 @@
 #pragma once
 
 #include <QFileInfo>
+#include <QJsonObject>
 #include <QObject>
 
+#include <KOSRelease>
+
 #include <automaticcoredumpexcavator.h>
 
 class Coredump;
@@ -28,17 +31,25 @@ class Patient : public QObject
     MEMBER_PROPERTY(time_t, timestamp) = 0;
 #undef MEMBER_PROPERTY
     Q_PROPERTY(bool canDebug READ canDebug NOTIFY changed)
+    Q_PROPERTY(bool canReport READ canReport NOTIFY changed)
     Q_PROPERTY(QString dateTime READ dateTime NOTIFY changed)
     Q_PROPERTY(QString iconName READ iconName CONSTANT)
+    Q_PROPERTY(QString faultEntityName READ faultEntityName CONSTANT)
+    Q_PROPERTY(QString journalCursor MEMBER m_journalCursor CONSTANT)
 public:
     explicit Patient(const Coredump &dump);
 
     QStringList coredumpctlArguments(const QString &command) const;
 
-    bool canDebug();
+    bool canDebug() const;
+    Q_INVOKABLE [[nodiscard]] QString reasonForNoDebug() const;
     Q_INVOKABLE void debug();
     QString dateTime() const;
     QString iconName() const;
+    [[nodiscard]] QString faultEntityName() const;
+    [[nodiscard]] bool canReport();
+    Q_INVOKABLE [[nodiscard]] QString reasonForNoReport() const;
+    Q_INVOKABLE void report();
 
 Q_SIGNALS:
     void changed();
@@ -51,6 +62,23 @@ private:
     const QByteArray m_coredumpCom;
     QString m_iconName;
     std::unique_ptr<AutomaticCoredumpExcavator> m_excavator;
+    QByteArray m_systemUnit;
+    QByteArray m_userUnit;
+    KOSRelease m_osRelease;
+    struct FaultContext {
+        enum class Entity {
+            Flatpak,
+            Snap,
+            KDE,
+            Distro // always when unknown
+        };
+        Entity entity;
+        QString name;
+        QString drkonqiMetadataPath = {}; // NOLINT this is not a redundant init!
+        QJsonObject drkonqiMetadata = {}; // NOLINT this is not a redundant init!
+        bool reportedToKDE = false;
+    } m_faultContext;
+    QString m_journalCursor;
 };
 
 Q_DECLARE_METATYPE(time_t)
